<?php

class User{

	private $user_params = [
		'user_id' => null,
		'name' => '',
		'slug' => '',
		'level' => null,
		'rank' => null,
		'battle_id' => null,
		'realm' => ''
	];

	private $user_table = '#__wow_guild_user_user';

	public function isUserExistsByName($name){
		$db = JFactory::getDbo();
		$query = $db->getQuery(true);

		$query->select('count(*) as count');
		$query->from($db->quoteName($this->user_table));
		$query->where($db->quoteName('name') . ' = ' . $db->quote($name));

		$db->setQuery($query);
		$results = $db->loadObject();

		return ($results->count > 0);
	}

	public function isUserExistsByUserId($id){
		$db = JFactory::getDbo();
		$query = $db->getQuery(true);

		$query->select('count(*) as count');
		$query->from($db->quoteName($this->user_table));
		$query->where($db->quoteName('user') . ' = ' . $db->quote($id));

		$db->setQuery($query);
		$results = $db->loadObject();

		return ($results->count > 0) ? false : true;
	}

	private function update(){

		$db = JFactory::getDbo();
		$query = $db->getQuery(true);

		$fields = [];
		foreach($this->user_params as $key => $params){
			if($key !== 'user_id'){
				$fields[] = $db->quoteName($key) . ' = ' . (is_int($params) ? $params : $db->quote($params));
			}
		}

		$conditions = $db->quoteName('battle_id') . ' = ' . $this->user_params['battle_id'];

		$query->update($db->quoteName($this->user_table))->set($fields)->where($conditions);
		$db->setQuery($query);
		$db->execute();
	}

	private function insert(){

		$db = JFactory::getDbo();
		$query = $db->getQuery(true);


		$values = [];
		foreach($this->user_params as $key => $params){
			$values[$key] = is_int($params) ? $params : $db->quote($params);
		}

		$values['checked_out_time'] = $db->quote(date('Y-m-d H:i:s'));

		$query
			->insert($db->quoteName($this->user_table))
			->columns($db->quoteName(array_keys($values)))
			->values(implode(',', $values));

		$db->setQuery($query);
		$db->execute();
	}

	public function save(){
		if($this->isUserExistsByName($this->get('name'))){
			$this->update();
		}else{
			$this->insert();
		}
	}

	function getNameSlug($name){
		return urlencode(strtolower($name));
	}

	public function get($name){
		return $this->user_params[$name];
	}

	public function set($name, $value){

		if($name === 'name'){
			$this->user_params['slug'] = $this->getNameSlug($value);
		}

		$this->user_params[$name] = $value;
		return $this;
	}

}
