<?php
/**
 * @package     Joomla.Plugin
 * @subpackage  Captcha
 *
 * @copyright   (C) 2011 Open Source Matters, Inc. <https://www.joomla.org>
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

require_once 'User.php';

class PlgContentUsersync extends JPlugin
{

	protected $autoloadLanguage = true;

	private $realm_slug;
	private $guild_slug;
	private $namespace;
	private $locale;
	private $token;

	public function __construct(&$subject, $config = array()){

		parent::__construct($subject, $config);

		$this->realm_slug = $this->params->get('realm_slug');
		$this->guild_slug = $this->params->get('guild_slug');
		$this->namespace = $this->params->get('namespace');
		$this->locale = $this->params->get('locale');
	}

	function isPluginBattlenetActive(){
		return !(empty(JPluginHelper::getPlugin('system', 'battlenet')));
	}

	function getToken(){
		$battlenet_config = JPluginHelper::getPlugin('system', 'battlenet');
		$token = json_decode($battlenet_config->params)->client_token;
		return $token;
	}

	function requestGetGuildRoster(){

		$curl = curl_init();

		curl_setopt_array($curl, array(
			CURLOPT_URL => 'https://eu.api.blizzard.com/data/wow/guild/'.$this->realm_slug.'/'.$this->guild_slug.'/roster?namespace='.$this->namespace.'&access_token='.$this->token.'&locale='.$this->locale,
			CURLOPT_RETURNTRANSFER => true,
			CURLOPT_ENCODING => '',
			CURLOPT_MAXREDIRS => 10,
			CURLOPT_TIMEOUT => 0,
			CURLOPT_FOLLOWLOCATION => true,
			CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
			CURLOPT_CUSTOMREQUEST => 'GET',
		));

		$response = curl_exec($curl);

		curl_close($curl);

		/**
		 * stdClass Object
		(
		[access_token] => USxBBl7P6336Kk1cwVhlI9B8d3pc9RR4vT
		[token_type] => bearer
		[expires_in] => 86399
		[sub] => aa0c7df71dfa4e9194998c6797fa61f4
		)
		 */
		return json_decode($response);
	}

	public function cronUpdate(){

		if($this->isPluginBattlenetActive()){
			$this->token = $this->getToken();
			$guild_roster = $this->requestGetGuildRoster();

			$guild = $guild_roster->guild;
			$members = $guild_roster->members;

			foreach($members as $member){

				$character = $member->character;
				$user = new User();
				$user->set('name', $character->name);
				$user->set('level', $character->level);
				$user->set('rank', $member->rank);
				$user->set('battle_id', $character->id);
				$user->set('realm', $character->realm->slug);
				$user->save();

			}
		}
	}

}
